==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/StrategyBasedIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialIndicatorDescriptionMetadata } from "./FinancialIndicatorDescriptionMetadata";
/**
 * @hidden
 */
var StrategyBasedIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StrategyBasedIndicatorDescriptionMetadata, _super);
    function StrategyBasedIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StrategyBasedIndicatorDescriptionMetadata.b = function (a) {
        if (StrategyBasedIndicatorDescriptionMetadata.a == null) {
            StrategyBasedIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StrategyBasedIndicatorDescriptionMetadata.c(StrategyBasedIndicatorDescriptionMetadata.a);
        }
        if (a.g(StrategyBasedIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(StrategyBasedIndicatorDescriptionMetadata.a);
    };
    StrategyBasedIndicatorDescriptionMetadata.c = function (a) {
        FinancialIndicatorDescriptionMetadata.c(a);
    };
    StrategyBasedIndicatorDescriptionMetadata.d = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.b(a);
        a.t("StrategyBasedIndicator", StrategyBasedIndicatorDescriptionMetadata.a);
    };
    StrategyBasedIndicatorDescriptionMetadata.$t = markType(StrategyBasedIndicatorDescriptionMetadata, 'StrategyBasedIndicatorDescriptionMetadata');
    StrategyBasedIndicatorDescriptionMetadata.a = null;
    return StrategyBasedIndicatorDescriptionMetadata;
}(Base));
export { StrategyBasedIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/StrategyBasedIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialIndicatorDescriptionMetadata } from "./FinancialIndicatorDescriptionMetadata";
/**
 * @hidden
 */
var StrategyBasedIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StrategyBasedIndicatorDescriptionMetadata, _super);
    function StrategyBasedIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StrategyBasedIndicatorDescriptionMetadata.b = function (a) {
        if (StrategyBasedIndicatorDescriptionMetadata.a == null) {
            StrategyBasedIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StrategyBasedIndicatorDescriptionMetadata.c(StrategyBasedIndicatorDescriptionMetadata.a);
        }
        if (a.j(StrategyBasedIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(StrategyBasedIndicatorDescriptionMetadata.a);
    };
    StrategyBasedIndicatorDescriptionMetadata.c = function (a) {
        FinancialIndicatorDescriptionMetadata.c(a);
    };
    StrategyBasedIndicatorDescriptionMetadata.d = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.b(a);
        a.z("StrategyBasedIndicator", StrategyBasedIndicatorDescriptionMetadata.a);
    };
    StrategyBasedIndicatorDescriptionMetadata.$t = markType(StrategyBasedIndicatorDescriptionMetadata, 'StrategyBasedIndicatorDescriptionMetadata');
    StrategyBasedIndicatorDescriptionMetadata.a = null;
    return StrategyBasedIndicatorDescriptionMetadata;
}(Base));
export { StrategyBasedIndicatorDescriptionMetadata };
